=================
``fields`` module
=================

.. automodule:: whoosh.fields

Schema class
============

.. autoclass:: Schema
    :members:


FieldType base class
====================

.. autoclass:: FieldType
    :members:


Pre-made field types
====================

.. autoclass:: ID
.. autoclass:: IDLIST
.. autoclass:: STORED
.. autoclass:: KEYWORD
.. autoclass:: TEXT
.. autoclass:: NUMERIC
.. autoclass:: DATETIME
.. autoclass:: BOOLEAN
.. autoclass:: NGRAM
.. autoclass:: NGRAMWORDS


Exceptions
==========

.. autoexception:: FieldConfigurationError
.. autoexception:: UnknownFieldError
